pub struct AggregationFilter {
pub aggregation_settings: Option<Box<AggregationSettings>>,
}Expand description
AggregationFilter : Use this filter to select the aggregation time period at which to send notifications (e.g. limit to one notification every five minutes for high frequency notifications).
Fields
aggregation_settings: Option<Box<AggregationSettings>>Implementations
sourceimpl AggregationFilter
impl AggregationFilter
sourcepub fn new() -> AggregationFilter
pub fn new() -> AggregationFilter
Use this filter to select the aggregation time period at which to send notifications (e.g. limit to one notification every five minutes for high frequency notifications).